## Replicates the empirical results in the paper.

# Load procedures
load("procedures.r")

# Load dataset and perform elementary cleaning procedures
dat.base  <- data.frame(read.dta("usmen8385_occ.dta")[,c(1:9,21:22)])
dat.treat <- data.frame(read.dta("usmen0305_occ.dta")[,c(1:9,21:22)])

dat.base[,11] <- as.numeric(dat.base[,"uhrswk"] <= 39)
dat.treat[,11] <- as.numeric(dat.treat[,"uhrswk"] <= 39)
names(dat.base)[11] <- "partt"
names(dat.treat)[11] <- "partt"

dat.base <- dat.base[-which((dat.base[,"uhrswk"]==0)),]

weights.base <- dat.base[,"eweight"] * dat.base[,"uhrswk"]
weights.treat <- dat.treat[,"eweight"] * dat.treat[,"uhrswk"]

# Compute a table of summary statistics
sumstat <- matrix(NA,ncol=10,nrow=7)

for (i in 1:7) {
 sumstat[i,] <- c(wtd.mean(dat.base[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.base, normwt=TRUE),
                  wtd.var(dat.base[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.base, normwt=TRUE)^.5,
                  wtd.quantile(dat.base[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.base, normwt=TRUE, prob=c(.1,.5,.9)),
                  wtd.mean(dat.treat[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.treat, normwt=TRUE),
                  wtd.var(dat.treat[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.treat, normwt=TRUE)^.5,
                  wtd.quantile(dat.treat[,c("lwage1", "partt","nonwhite","covered","marr","educ","exper")[i]], w=weights.treat, normwt=TRUE, prob=c(.1,.5,.9)))
}
xtable(sumstat,digits=3)

# Compute the full decomposition
dat <- list(NA)
dat[[1]] <- dat.base
dat[[2]] <- dat.treat

weights <- list(NA)
weights[[1]] <- weights.base
weights[[2]] <- weights.treat

set.seed(12345) # to ensure constancy of results based on MC integration
out.table <- full.decomp(formula = lwage1~(partt+nonwhite+covered+marr+educ+I(educ^2)+exper+I((exper^2)/100))^2,
                         covariate = ~partt+nonwhite+covered+marr+educ+exper,
                         dat = dat, weights = weights)
set.seed(as.numeric(format(Sys.time(), "%OS3"))*1000)

save(out.table,file="output.Rdata")


## Compute bootstrap standard errors

out.list <- list(NA)
bskip <- 1   # Set to positive integer to use a m-out-of-n bootstrap (useful for
             # large data sets.
for (b in 1:200) {

 bsamp1 <- sample(1:length(weights.base), round(length(weights.base)/bskip), replace=TRUE, prob=weights.base)
 bsamp2 <- sample(1:length(weights.treat), round(length(weights.treat)/bskip), replace=TRUE, prob=weights.treat)
 
 dat <- list(NA)
 dat[[1]] <- dat.base[bsamp1,]
 dat[[2]] <- dat.treat[bsamp2,]

 ww <- list(NA)
 ww[[1]] <- rep(1,length(bsamp1))
 ww[[2]] <- rep(1,length(bsamp2))
 

 set.seed(12345) # to ensure constancy of results based on MC integration
 out.list[[b]] <- full.decomp(formula = lwage1~(partt+nonwhite+covered+marr+educ+I(educ^2)+exper+I((exper^2)/100))^2,
                               covariate = ~partt+nonwhite+covered+marr+educ+exper,
                               dat = dat, weights = ww)   
 set.seed(as.numeric(format(Sys.time(), "%OS3"))*1000)                             
 
 save(out.list,file="outlist.Rdata")
 print(c("BOOTSTRAP REPLICATION: ", b))
}
 

 sd.table <- out.table
 
 for (i in 1:dim(sd.table)[1]) {
  for (j in 1:dim(sd.table)[2]) {
   sd.table[i,j]  <- sd(sapply(out.list, function(x) {x[i,j]})/sqrt(bskip))
   }
 }
 
 
 tab1 <- out.table[,1:8] 
 for (i in 1:4) {
  tab1[,1 + 2*(i-1)] <- out.table[,i]
  tab1[,2 + 2*(i-1)] <- sd.table[,i]
   }
 colnames(tab1) <- c("mean","mean.se","q90","q90.se","q50","q50.se","q10","q10.se")
 xtable(100*tab1,digits=3)
 
  tab2 <- out.table[,1:8] 
 for (i in 1:4) {
  tab2[,1 + 2*(i-1)] <- out.table[,c(8,5:7)][,i]
  tab2[,2 + 2*(i-1)] <- sd.table[,c(8,5:7)][,i]
   }
 colnames(tab2) <- c("sd","sd.se","q9010","q9010.se","q9050","q9050.se","q5010","q5010.se")
 xtable(100*tab2,digits=3)
 